#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hxt-charproperties
version:              9.5.0.0
visibility:           public
id:                   hxt-charproperties-9.5.0.0-Clx9JIwkEDM2QdcnTbIXsE
key:                  hxt-charproperties-9.5.0.0-Clx9JIwkEDM2QdcnTbIXsE
license:              MIT
copyright:            Copyright (c) 2010- Uwe Schmidt
maintainer:           Uwe Schmidt <uwe@fh-wedel.de>
author:               Uwe Schmidt
stability:            Stable
homepage:             https://github.com/UweSchmidt/hxt
synopsis:             Character properties and classes for XML and Unicode
description:
    Character properties defined by XML and Unicode standards.
    These modules contain predicates for Unicode blocks,
    char properties
    and character predicates defined by XML.
    Supported Unicode version is 13.0.0
    9.4.0.0: Supported Unicode version 12.1.0
    9.3.0.2: Supported Unicode version 9.0.0

category:             Text
abi:                  766b6046a8ef5c4b606f2b76f523e66b
exposed:              True
exposed-modules:
    Data.Char.Properties.UnicodeBlocks
    Data.Char.Properties.UnicodeCharProps
    Data.Char.Properties.XMLCharProps Data.Set.CharSet

import-dirs:          /usr/lib/ghc-8.10.5/site-local/hxt-charproperties-9.5.0.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/hxt-charproperties-9.5.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/hxt-charproperties-9.5.0.0
hs-libraries:         HShxt-charproperties-9.5.0.0-Clx9JIwkEDM2QdcnTbIXsE
depends:              base-4.14.2.0
haddock-interfaces:
    /usr/share/doc/haskell-hxt-charproperties/html/hxt-charproperties.haddock

haddock-html:         /usr/share/doc/haskell-hxt-charproperties/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

